package Task::Munin;
use strict;
use warnings;
use 5.008005;

our $VERSION = '0.01';

=head1 SYNOPSIS

Task::Munin - an unoffical module listing the dependencies of Munin

=head1 DESCRIPTION

L<Munin|http://munin-monitoring.org/>

=head1 AUTHOR

L<Gabor Szabo|http://szabgab.com/>

=cut


1;

